diff --git a/CMakeLists.txt b/CMakeLists.txt
index b4afcb941812f6c05697c6ecedb2b986d6766a74..c045f0c5721b4bcd3b6e594822c89e6ad3e78e56 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -188,7 +188,7 @@ if(MSVC)
 
     # daemon
     set(DRING_SRC_PATH ${DRING}/contrib/msvc/include)
-    set(DRING_LIB ${DRING}/build/x64/ReleaseLib_win32/bin/dring.lib)
+    set(DRING_LIB ${DRING}/build/x64/ReleaseLib_win32/bin/jami.lib)
     set(GNUTLS_LIB ${DRING}/contrib/msvc/lib/x64/libgnutls.lib)
 
     # ReleaseCompile config
diff --git a/INSTALL.md b/INSTALL.md
index 7dabb8a45481c0fa8b69c1d328353a55c2cbbf39..031a8c3f349e6c3dbf4b7bbc0023f384164c2831 100644
--- a/INSTALL.md
+++ b/INSTALL.md
@@ -34,7 +34,7 @@ Then, you can build daemon, lrc and client-qt with:
 ./build.py --install --qt
 ```
 
-And you will have the daemon in `daemon/bin/dring` and the client in `client-qt/build-local/jami-qt`. You also can run it with
+And you will have the daemon in `daemon/bin/jamid` and the client in `client-qt/build-local/jami-qt`. You also can run it with
 
 If you use a Qt version that is not wide-system installed you need to specify its path after the `--qt` flag, i. e., `./build.py --install --qt /home/<username>/Qt/5.15.0/gcc_64
 
diff --git a/compile_tests.sh b/compile_tests.sh
index 26c5759f4488c7525b8b777bc16b37fddb169709..e8c6457d72b26b569d7e211cd53981b2b4908ea8 100755
--- a/compile_tests.sh
+++ b/compile_tests.sh
@@ -19,7 +19,7 @@ mkdir -p build
 cd build
 echo "Building lrc in "$PWD
 cmake .. -DCMAKE_INSTALL_PREFIX=$installDir/lrc \
-      -DRING_INCLUDE_DIR=$daemonDir/src/dring \
+      -DRING_INCLUDE_DIR=$daemonDir/src/jami \
       -DRING_XML_INTERFACES_DIR=$daemonDir/bin/dbus
 make -j${cpuCount}
 make install
diff --git a/doc/jami-qt.1 b/doc/jami-qt.1
index e616b104424034ad69056defebc961d81d68f3ce..9e4f4c0dfea3ad5e90b6c8b329bd9f5c0e4cac71 100644
--- a/doc/jami-qt.1
+++ b/doc/jami-qt.1
@@ -16,6 +16,6 @@ Enable debug.
 .B \-h, \-\-help
 Display help text and exit.
 .SH SEE ALSO
-dring(1)
+jamid(1)
 .SH AUTHOR
 Alexandre Viau (alexandre.viau@savoirfairelinux.net)
diff --git a/make-client.py b/make-client.py
index 30800e75ad90259d2b93684b39964c3cafbb17f4..2caa851eaab7afabe369253a5e558ee50d52c92b 100644
--- a/make-client.py
+++ b/make-client.py
@@ -297,14 +297,14 @@ def build_tests_projects(arch, config_str, msbuild, vs_env_vars, toolset,
         msbuild_args = getMSBuildArgs(arch, config_str, toolset)
         build_project(msbuild, msbuild_args, project, vs_env_vars)
 
-def run_tests(mute_dring, output_to_files):
+def run_tests(mute_jamid, output_to_files):
     print('Running client tests')
 
     test_exe_command_list = [qml_test_exe, unit_test_exe]
 
-    if mute_dring:
-        test_exe_command_list[0] += ' -mutedring'
-        test_exe_command_list[1] += ' -mutedring'
+    if mute_jamid:
+        test_exe_command_list[0] += ' -mutejami'
+        test_exe_command_list[1] += ' -mutejami'
     if output_to_files:
         test_exe_command_list[0] += ' -o ' + this_dir + '\\x64\\test\\qml_tests.txt'
         test_exe_command_list[1] += ' > ' + this_dir + '\\x64\\test\\unittests.txt'
@@ -359,8 +359,8 @@ def parse_args():
 
     run_test = subparser.add_parser('runtests')
     run_test.add_argument(
-        '-md', '--mutedring', action='store_true', default=False,
-        help='Avoid dring logs')
+        '-md', '--mutejami', action='store_true', default=False,
+        help='Avoid jamid logs')
     run_test.add_argument(
         '-o', '--outputtofiles', action='store_true', default=False,
         help='Output tests log into files')
@@ -391,7 +391,7 @@ def main():
         enable_test = True
 
     if parsed_args.subparser_name == 'runtests':
-        run_tests(parsed_args.mutedring, parsed_args.outputtofiles)
+        run_tests(parsed_args.mutejamid, parsed_args.outputtofiles)
 
     if parsed_args.deps:
         deps(parsed_args.arch, parsed_args.toolset, parsed_args.qtver)
diff --git a/src/DaemonReconnectWindow.qml b/src/DaemonReconnectWindow.qml
index 8d7a64755ed73aa33a4ce3bea29a17eb7a43e412..fa1eb907c5542df49e8cea9e8fd317c573e43f06 100644
--- a/src/DaemonReconnectWindow.qml
+++ b/src/DaemonReconnectWindow.qml
@@ -95,8 +95,8 @@ ApplicationWindow {
                     Layout.topMargin: preferredMargin
 
                     text: connectionFailed ?
-                              qsTr("Could not re-connect to the Jami daemon (dring).\nJami will now quit.") :
-                              qsTr("Trying to reconnect to the Jami daemon (dring)…")
+                              qsTr("Could not re-connect to the Jami daemon (jamid).\nJami will now quit.") :
+                              qsTr("Trying to reconnect to the Jami daemon (jamid)…")
                     font.pointSize: 11
                     horizontalAlignment: Text.AlignHCenter
                     verticalAlignment: Text.AlignVCenter
diff --git a/src/constant/JamiStrings.qml b/src/constant/JamiStrings.qml
index 21bf7865ca0be704a0e09d97889554bf6afade41..5a98bf3a3422d355628f26b0adeba380e5c2dbd4 100644
--- a/src/constant/JamiStrings.qml
+++ b/src/constant/JamiStrings.qml
@@ -478,8 +478,8 @@ Item {
     property string removeDefaultModerator: qsTr("Remove default moderator")
 
     // Daemon reconnection
-    property string reconnectDaemon: qsTr("Trying to reconnect to the Jami daemon (dring)…")
-    property string reconnectionFailed: qsTr("Could not re-connect to the Jami daemon (dring).\nJami will now quit.")
+    property string reconnectDaemon: qsTr("Trying to reconnect to the Jami daemon (jamid)…")
+    property string reconnectionFailed: qsTr("Could not re-connect to the Jami daemon (jamid).\nJami will now quit.")
 
     // Is Swarm
     property string isSwarm: qsTr("Is swarm:")
diff --git a/tests/qml/main.cpp b/tests/qml/main.cpp
index c99c569ba6f4cc67cf28751750d22fc918dc9e99..cf8e17c84b179a897b1486edac56a8ea9f65f945 100644
--- a/tests/qml/main.cpp
+++ b/tests/qml/main.cpp
@@ -182,10 +182,10 @@ main(int argc, char** argv)
 {
     bool muteDring {false};
 
     // Remove "-mutedring" from argv, as quick_test_main_with_setup() will
     // fail if given an invalid command-line argument.
     auto end = std::remove_if(argv + 1, argv + argc, [](char* argv) {
-        return (strcmp(argv, "-mutedring") == 0);
+        return (strcmp(argv, "-mutejami") == 0);
     });
 
     if (end != argv + argc) {
@@ -182,10 +182,10 @@ main(int argc, char** argv)
     bool muteDring {false};
 
-    // Remove "-mutedring" from argv, as quick_test_main_with_setup() will
+    // Remove "-mutejami" from argv, as quick_test_main_with_setup() will
     // fail if given an invalid command-line argument.
     auto end = std::remove_if(argv + 1, argv + argc, [](char* argv) {
diff --git a/tests/unittests/main_unittest.cpp b/tests/unittests/main_unittest.cpp
index 1d477c15dd5ab0ed38533d417ff257a34c64cfc2..2c6380b47f9ed8493dd003f579223f3dec99f831 100644
--- a/tests/unittests/main_unittest.cpp
+++ b/tests/unittests/main_unittest.cpp
@@ -27,10 +27,10 @@ TestEnvironment globalEnv;
 int
 main(int argc, char* argv[])
 {
     // Remove "-mutedring" from argv, as quick_test_main_with_setup() will
     // fail if given an invalid command-line argument.
     auto end = std::remove_if(argv + 1, argv + argc, [](char* argv) {
-        return (strcmp(argv, "-mutedring") == 0);
+        return (strcmp(argv, "-mutejami") == 0);
     });
 
     if (end != argv + argc) {
@@ -27,10 +27,10 @@ TestEnvironment globalEnv;
 main(int argc, char* argv[])
 {
-    // Remove "-mutedring" from argv, as quick_test_main_with_setup() will
+    // Remove "-mutejami" from argv, as quick_test_main_with_setup() will
     // fail if given an invalid command-line argument.
     auto end = std::remove_if(argv + 1, argv + argc, [](char* argv) {